#
# spec file for package libavc1394
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libavc1394
Version:        0.5.4
Release:        20.1
Summary:        Programming Interface to the AV/C Specification
License:        LGPL-2.1-or-later AND GPL-2.0-or-later
Group:          System/Libraries
URL:            https://sourceforge.net/projects/libavc1394/
Source:         https://downloads.sf.net/libavc1394/%{name}-%{version}.tar.gz
Source2:        baselibs.conf
Patch0:         libavc1394.no-mkrfc2734.patch
Patch1:         libavc1394.raw1394_set_fcp_handler.patch
Patch2:         libavc-fix-symbolexports.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libraw1394-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig

%description
libavc1394 is a programming interface to the AV/C (Audio/Video
Control) specification. Applications use the library to control the
tape transport mechanism on DV camcorders. However, there are many
devices and functions of devices that can be controlled via AV/C.

%package 0
Summary:        Programming Interface to the AV/C Specification
License:        LGPL-2.1-or-later AND GPL-2.0-or-later
Group:          System/Libraries

%description 0
libavc1394 is a programming interface to the AV/C (Audio/Video
Control) specification. Applications use the library to control the
tape transport mechanism on DV camcorders. However, there are many
devices and functions of devices that can be controlled via AV/C.

%package devel
Summary:        Development files for libavc1394, a library to the AV/C specification
License:        LGPL-2.1-or-later AND GPL-2.0-or-later
Group:          Development/Libraries/C and C++
Requires:       libavc1394-0 = %{version}

%description devel
libavc1394 is a programming interface to the AV/C (Audio/Video
Control) specification. Applications use the library to control the
tape transport mechanism on DV camcorders. However, there are many
devices and functions of devices that can be controlled via AV/C.

%package tools
Summary:        Utilities for AV/C 1394
# added on 2015-11-14
License:        GPL-2.0-or-later
Group:          Hardware/Other
Obsoletes:      %{name} < %{version}-%{release}
Provides:       %{name} = %{version}-%{release}

%description tools
Command-line utilities to inspect and control AV/C hardware.

%prep
%autosetup -p1

%build
autoreconf -fvi
%configure --disable-static
make %{?_smp_mflags}

%install
%make_install %{?_smp_mflags}
find %{buildroot} -type f -name "*.la" -delete -print

%post 0 -p /sbin/ldconfig
%postun 0 -p /sbin/ldconfig

%files tools
%license COPYING
%doc README AUTHORS
%{_mandir}/man1/*
%{_bindir}/*

%files 0
%{_libdir}/libavc1394.so.*
%{_libdir}/librom1394.so.*

%files devel
%{_libdir}/*.so
%{_includedir}/libavc1394
%{_libdir}/pkgconfig/*.pc

%changelog
* Thu Feb 29 2024 pgajdos@suse.com
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Wed Aug 14 2019 Tomáš Chvátal <tchvatal@suse.com>
- Freshen a bit
* Sat Nov 14 2015 jengelh@inai.de
- Update groups and trim descriptions.
- Remove redundant --with-pic; shared libraries always get it
  anyway.
- Name the utility package -tools as with many other pkgs.
  Set its license.
* Sat Mar 21 2015 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Use url for source
- Remove obsolete ppc provides/obsoletes
* Thu Sep  4 2014 crrodriguez@opensuse.org
- Just like the companion librawxxx, this package has screwed
  symbol names, fix them by exporting only the public API.
  (libavc-fix-symbolexports.patch)
* Fri Dec  2 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Sun Oct  3 2010 davejplater@gmail.com
- Update to version 0.5.4
- Upstream changes :
  panelctl.[c1]: apply patch from Jerry Fiddler to add options --guid,
  - -specid, --swversion, and --commands.
* Fri Dec 18 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Fri Jan  9 2009 crrodriguez@suse.de
- remove static libraries and "la" files
* Wed Dec 10 2008 olh@suse.de
- use Obsoletes: -XXbit only for ppc64 to help solver during distupgrade
  (bnc#437293)
* Thu Dec  4 2008 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Mon Oct  6 2008 olh@suse.de
- fix ordered comparison of pointer with integer zero (bnc#431913)
* Wed May 21 2008 cthiel@suse.de
- fix baselibs.conf
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Sat Aug  4 2007 olh@suse.de
- remove mkrfc2734 for 2.4 kernel
  split libavc1394-0 package which contains only libraries
* Wed Jul 19 2006 olh@suse.de
- update to  0.5.3:
  bugfixes
  new avc1394_transaction_block2() function that returns the length
  of the response.
  Panel subunit indirect mode constants added to header.
  new panelctl utility based upon 6200ch and 6200cmd from MythTV developers.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Sep 26 2005 mls@suse.de
- make devel package require base package
* Sat Jul  2 2005 olh@suse.de
- package all *.so files
* Fri Jul  1 2005 olh@suse.de
- update to 0.5.1
* Sun Jan 11 2004 adrian@suse.de
- add %%run_ldconfig
* Thu Nov 13 2003 sf@suse.de
- update to 0.4.1
* Thu Jun 12 2003 coolo@suse.de
- fixing file list
* Thu Dec 12 2002 coolo@suse.de
- actually adding the patch may help (noone noticed? :)
* Wed Dec 11 2002 coolo@suse.de
- removed undefined symbols from the libraries
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Fri Jul 12 2002 meissner@suse.de
- rerurn auto* tools.
* Tue Mar 26 2002 sf@suse.de
- initial version 0.3.1
